﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using MySqlConnector;

namespace SampleWindow
{
    public partial class SampleForm : Form
    {
        private MySqlClient mySqlClient;

        public SampleForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// 接続ボタンClick
        /// </summary>
        private void ButtonConnect_Click(object sender, EventArgs e)
        {
            string connectionString = MySqlClient.CreateConnectionString(string.Format("Server={0}", this.TextBoxServer.Text.Trim()),
                string.Format("DataBase={0}", this.TextBoxDB.Text.Trim()), string.Format("User ID={0}", this.TextBoxUserID.Text.Trim()),
                string.Format("Password={0}", this.TextBoxPass.Text.Trim()), this.TextBoxOtherOP.Text.Trim());
            if ((this.mySqlClient == null) || (this.mySqlClient.State == ConnectionState.Closed)) {
                this.mySqlClient = new MySqlClient();
                MySqlResult result = this.mySqlClient.Connect(connectionString);
                this.LabelConnectState.Text = result.IsSuccess ? mySqlClient.State.ToString() : result.ErrorMessages[0];
            } else {
                this.LabelConnectState.Text = this.mySqlClient.State.ToString();
            }
        }

        /// <summary>
        /// 切断ボタンClick
        /// </summary>
        private void ButtonClose_Click(object sender, EventArgs e)
        {
            if (mySqlClient != null) {
                MySqlResult result = mySqlClient.Close();
                this.LabelConnectState.Text = result.IsSuccess ? mySqlClient.State.ToString() : result.ErrorMessages[0];
            } else {
                this.LabelConnectState.Text = ConnectionState.Closed.ToString();
            }
        }

        /// <summary>
        /// 実行ボタンClick
        /// </summary>
        private void ButtonExe_Click(object sender, EventArgs e)
        {
            if ((this.mySqlClient == null) || (this.mySqlClient.State != ConnectionState.Open)) {
                this.LabelResult.Text = "MySQL Connection is not Open. Please Connect MySQL.";
                return;
            }

            if (this.RadioSelect.Checked || this.RadioShow.Checked) {
                MySqlResult<DataTable> result = this.mySqlClient.GetSearchResultTable(this.TextBoxSql.Text.Trim(), false);

                if (!result.IsSuccess) {
                    this.LabelResult.Text = result.ErrorMessages[0];
                    return;
                }

                this.DataGridResult.DataSource = result.Value;
            } else {
                MySqlResult result = null;
                if (this.RadioInsert.Checked) {
                    result = this.mySqlClient.InsertData(this.TextBoxSql.Text.Trim(), false);
                } else if (this.RadioUpdate.Checked) {
                    result = this.mySqlClient.UpdateData(this.TextBoxSql.Text.Trim(), false);
                } else if (this.RadioDelete.Checked) {
                    result = this.mySqlClient.DeleteData(this.TextBoxSql.Text.Trim(), false);
                } else if (this.RadioOther.Checked) {
                    result = this.mySqlClient.ExecuteSql(this.TextBoxSql.Text.Trim(), false);
                }

                if (!result.IsSuccess) {
                    this.LabelResult.Text = result.ErrorMessages[0];
                    return;
                }

                this.DataGridResult.DataSource = null;
            }

            this.LabelResult.Text = "Sql Execute Success.";
        }
    }
}
